@@ -1,5 +1,6 @@
 // -*- c-basic-offset: 4; -*-
 #include "RNG.h"
+#include <cmath>
 
 // #ifdef USE_R
 // #include "RRNG.cpp"
@@ -7,6 +8,12 @@
 // #include "GRNG.cpp"
 // #endif
 
+using std::pow;
+using std::fabs;
+using std::sqrt;
+using std::log;
+using std::exp;
+
 // Throw runtime exception or return.
 #ifndef TREOR
 #ifndef NTHROW
